Translate Toolkit 1.8.0 — Translate Toolkit 3.1.0 documentation

Translate Toolkit 3.1.0

- Site
  - Features
  - Installation
  - Converters
  - Tools
  - Scripts
  - Use Cases
  - Supported formats
  - Translate Styleguide
  - Documentation
  - Building
  - Testing
  - Command Line Functional Testing
  - Contributing
  - Translate Toolkit Developers Guide
  - Making a Translate Toolkit Release
  - Deprecation of Features
  - Release Notes
  - History of the Translate Toolkit
  - License
  - API
- Page
  - Translate Toolkit 1.8.0
- « Translate Toolkit 1.8.1
- Translate Toolkit 1.7.0 »

# Translate Toolkit 1.8.0

Released on 17 August 2010

Release notes for this release are still to be recovered, feel free to do some way back searching and create a Pull Request for this release.